@@ -17,14 +17,13 @@
 """Python bindings for Subversion."""
 
 __author__ = "Jelmer Vernooij <jelmer@samba.org>"
-__version__ = (0, 7, 5)
+__version__ = (0, 8, 1)
 
 NODE_DIR = 2
 NODE_FILE = 1
 NODE_NONE = 0
 NODE_UNKNOWN = 3
 
-ERR_UNKNOWN_HOSTNAME = 670002
 ERR_UNSUPPORTED_FEATURE = 200007
 ERR_RA_SVN_UNKNOWN_CMD = 210001
 ERR_RA_SVN_CONNECTION_CLOSED = 210002
@@ -68,7 +67,6 @@ ERR_RA_DAV_FORBIDDEN = 175013
 ERR_WC_SCHEDULE_CONFLICT = 155013
 ERR_RA_DAV_PROPPATCH_FAILED = 175008
 ERR_SVNDIFF_CORRUPT_WINDOW = 185001
-ERR_EAI_NONAME = 670008
 ERR_FS_CONFLICT = 160024
 ERR_NODE_UNKNOWN_KIND = 145000
 ERR_RA_SERF_SSL_CERT_UNTRUSTED = 230001
@@ -76,6 +74,12 @@ ERR_ENTRY_NOT_FOUND = 150000
 
 ERR_APR_OS_START_EAIERR = 670000
 ERR_APR_OS_ERRSPACE_SIZE = 50000
+ERR_CATEGORY_SIZE = 5000
+
+
+# These will be removed in the next version of subvertpy
+ERR_EAI_NONAME = 670008
+ERR_UNKNOWN_HOSTNAME = 670002
 
 AUTH_PARAM_DEFAULT_USERNAME = 'svn:auth:username'
 AUTH_PARAM_DEFAULT_PASSWORD = 'svn:auth:password'
