@@ -404,13 +404,16 @@ static PyObject *api_version(PyObject *self)
 						 ver->patch, ver->tag);
 }
 
-
-
-
 static PyMethodDef repos_module_methods[] = {
-	{ "create", (PyCFunction)repos_create, METH_VARARGS, NULL },
-	{ "delete", (PyCFunction)repos_delete, METH_VARARGS, NULL },
-	{ "hotcopy", (PyCFunction)repos_hotcopy, METH_VARARGS, NULL },
+	{ "create", (PyCFunction)repos_create, METH_VARARGS, 
+		"create(path, config=None, fs_config=None)\n\n"
+		"Create a new repository." },
+	{ "delete", (PyCFunction)repos_delete, METH_VARARGS, 
+		"delete(path)\n\n"
+		"Delete a repository." },
+	{ "hotcopy", (PyCFunction)repos_hotcopy, METH_VARARGS, 
+		"hotcopy(src_path, dest_path, clean_logs=False)\n\n"
+		"Make a hot copy of a repository." },
 	{ "api_version", (PyCFunction)api_version, METH_NOARGS,
 		"api_version() -> (major, minor, patch, tag)\n\n"
 		"Version of libsvn_client Subvertpy was compiled against."
@@ -425,7 +428,7 @@ static PyMethodDef repos_module_methods[] = {
 
 static PyObject *repos_has_capability(RepositoryObject *self, PyObject *args)
 {
-#if SVN_VER_MAJOR >= 1 && SVN_VER_MINOR >= 5
+#if ONLY_SINCE_SVN(1, 5)
 	char *name;
 	svn_boolean_t has;
 	apr_pool_t *temp_pool;
@@ -485,7 +488,7 @@ PyTypeObject Repository_Type = {
 	/* Flags to define presence of optional/expanded features */
 	0, /*	long tp_flags;	*/
 	
-	NULL, /*	const char *tp_doc;  Documentation string */
+	"Local repository", /*	const char *tp_doc;  Documentation string */
 	
 	/* Assigned meaning in release 2.0 */
 	/* call function for all accessible objects */
@@ -544,6 +547,48 @@ static PyObject *py_string_from_svn_node_id(const svn_fs_id_t *id)
 	return PyString_FromStringAndSize(str->data, str->len);
 }
 
+#if ONLY_BEFORE_SVN(1, 6)
+static PyObject *py_fs_path_change(svn_fs_path_change_t *val)
+{
+	PyObject *ret, *py_node_id;
+
+	py_node_id = py_string_from_svn_node_id(val->node_rev_id);
+	if (py_node_id == NULL) {
+		return NULL;
+	}
+	ret = Py_BuildValue("(Oibb)", py_node_id,
+						   val->change_kind, val->text_mod, val->prop_mod);
+	Py_DECREF(py_node_id);
+	if (ret == NULL) {
+		return NULL;
+	}
+
+	return ret;
+}
+
+#else
+
+static PyObject *py_fs_path_change2(svn_fs_path_change2_t *val)
+{
+	PyObject *ret, *py_node_id;
+
+	py_node_id = py_string_from_svn_node_id(val->node_rev_id);
+	if (py_node_id == NULL) {
+		return NULL;
+	}
+	ret = Py_BuildValue("(Oibb)", py_node_id,
+						   val->change_kind, val->text_mod, val->prop_mod);
+	Py_DECREF(py_node_id);
+	if (ret == NULL) {
+		return NULL;
+	}
+
+	/* FIXME: copyfrom information */
+
+	return ret;
+}
+#endif
+
 static PyObject *fs_root_paths_changed(FileSystemRootObject *self)
 {
 	apr_pool_t *temp_pool;
@@ -555,22 +600,28 @@ static PyObject *fs_root_paths_changed(FileSystemRootObject *self)
 	temp_pool = Pool(NULL);
 	if (temp_pool == NULL)
 		return NULL;
+#if ONLY_SINCE_SVN(1, 6)
+	RUN_SVN_WITH_POOL(temp_pool, 
+					  svn_fs_paths_changed2(&changed_paths, self->root, temp_pool));
+#else
 	RUN_SVN_WITH_POOL(temp_pool, 
 					  svn_fs_paths_changed(&changed_paths, self->root, temp_pool));
+#endif
 	ret = PyDict_New();
 	for (idx = apr_hash_first(temp_pool, changed_paths); idx != NULL;
 		 idx = apr_hash_next(idx)) {
-		PyObject *py_val, *py_node_id;
+		PyObject *py_val;
+#if ONLY_SINCE_SVN(1, 6)
+		svn_fs_path_change2_t *val;
+#else
 		svn_fs_path_change_t *val;
+#endif
 		apr_hash_this(idx, (const void **)&key, &klen, (void **)&val);
-		py_node_id = py_string_from_svn_node_id(val->node_rev_id);
-		if (py_node_id == NULL) {
-			apr_pool_destroy(temp_pool);
-			PyObject_Del(ret);
-			return NULL;
-		}
-		py_val = Py_BuildValue("(sibb)", py_node_id,
-							   val->change_kind, val->text_mod, val->prop_mod);
+#if ONLY_SINCE_SVN(1, 6)
+		py_val = py_fs_path_change2(val);
+#else
+		py_val = py_fs_path_change(val);
+#endif
 		if (py_val == NULL) {
 			apr_pool_destroy(temp_pool);
 			PyObject_Del(ret);
@@ -662,7 +713,7 @@ static PyObject *fs_root_file_checksum(FileSystemRootObject *self, PyObject *arg
 	apr_pool_t *temp_pool;
 	svn_boolean_t force = FALSE;
 	char *path;
-#if SVN_VER_MAJOR >= 1 && SVN_VER_MINOR >= 6
+#if ONLY_SINCE_SVN(1, 6)
 	svn_checksum_kind_t kind;
 	const char *cstr;
 	svn_checksum_t *checksum;
@@ -678,7 +729,7 @@ static PyObject *fs_root_file_checksum(FileSystemRootObject *self, PyObject *arg
 	temp_pool = Pool(NULL);
 	if (temp_pool == NULL)
 		return NULL;
-#if SVN_VER_MAJOR >= 1 && SVN_VER_MINOR >= 6
+#if ONLY_SINCE_SVN(1, 6)
 	RUN_SVN_WITH_POOL(temp_pool, svn_fs_file_checksum(&checksum, kind, 
 													  self->root, 
 											   path, force, temp_pool));
@@ -840,7 +891,7 @@ void initrepos(void)
 	PyModule_AddObject(mod, "PATH_CHANGE_DELETE", PyInt_FromLong(svn_fs_path_change_delete));
 	PyModule_AddObject(mod, "PATH_CHANGE_REPLACE", PyInt_FromLong(svn_fs_path_change_replace));
 
-#if SVN_VER_MAJOR >= 1 && SVN_VER_MINOR >= 6
+#if ONLY_SINCE_SVN(1, 6)
 	PyModule_AddObject(mod, "CHECKSUM_MD5", PyInt_FromLong(svn_checksum_md5));
 	PyModule_AddObject(mod, "CHECKSUM_SHA1", PyInt_FromLong(svn_checksum_sha1));
 #else
